
/*******************************************************************************
* Copyright (c) 2017 Olivier Langella <olivier.langella@u-psud.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <olivier.langella@u-psud.fr> - initial API and implementation
******************************************************************************/

#include <QDebug>
#include <pappsomspp/pappsoexception.h>
#include "proteintableproxymodel.h"
#include "proteintablemodel.h"
#include "proteinlistwindow.h"

ProteinTableProxyModel::ProteinTableProxyModel(ProteinListWindow * p_protein_list_window, ProteinTableModel* protein_table_model_p): QSortFilterProxyModel(protein_table_model_p)
{
    _protein_table_model_p = protein_table_model_p;
    _p_protein_list_window = p_protein_list_window;
}
bool ProteinTableProxyModel::filterAcceptsRow(int source_row,
        const QModelIndex &source_parent) const {
    try {
        //qDebug() << "ProteinTableProxyModel::filterAcceptsRow begin " << source_row;
        ProteinMatch * protein_match = _protein_table_model_p->getIdentificationGroup()->getProteinMatchList().at(source_row);
        //qDebug() << "ProteinTableProxyModel::filterAcceptsRow protein_match " << source_row;

        if (!_protein_search_string.isEmpty()) {
            if (_search_on == "accession") {
                if (!protein_match->getProteinXtpSp().get()->getAccession().contains(_protein_search_string)) {
                    return false;
                }
            }
            else if (_search_on == "group") {
                pappso::GrpProtein * p_grp_prot = protein_match->getGrpProteinSp().get();
                if (p_grp_prot == nullptr) {
                    return false;
                }
                else {
                    p_grp_prot->getGroupingId();
                    if (!p_grp_prot->getGroupingId().startsWith(_protein_search_string)) {
                        return false;
                    }
                }
            }
            else {
                if (!protein_match->getProteinXtpSp().get()->getDescription().contains(_protein_search_string)) {
                    return false;
                }
            }
        }

        //qDebug() << "ProteinTableProxyModel::filterAcceptsRow valid ";
        if (_hide_not_valid) {
            if (! protein_match->isValid()) {
                return false;
            }
        }
        //qDebug() << "ProteinTableProxyModel::filterAcceptsRow checked ";
        if (_hide_not_checked) {
            if (! protein_match->isChecked()) {
                return false;
            }
        }

        //qDebug() << "ProteinTableProxyModel::filterAcceptsRow grouped ";
        pappso::GrpProtein * p_grp_prot = protein_match->getGrpProteinSp().get();
        if (_hide_not_grouped) {
            if (p_grp_prot == nullptr) {
                return false;
            }

            //qDebug() << "ProteinTableProxyModel::filterAcceptsRow grouped 2";
            if (p_grp_prot->getGroupingId().isEmpty()) {
                return false;
            }
        }
    }

    catch (pappso::PappsoException exception_pappso) {
        //QMessageBox::warning(this,
        //                     tr("Error in ProteinTableModel::acceptRow :"), exception_pappso.qwhat());
        qDebug() << "Error in ProteinTableModel::acceptRow :" << exception_pappso.qwhat();
    }
    catch (std::exception exception_std) {
        //QMessageBox::warning(this,
        //                    tr("Error in ProteinTableModel::acceptRow :"), exception_std.what());
        qDebug() << "Error in ProteinTableModel::acceptRow :" << exception_std.what();
    }

    return true;

    //return true;
}



void ProteinTableProxyModel::onTableClicked(const QModelIndex &index)
{
    qDebug() << "ProteinTableProxyModel::onTableClicked begin " << index.row();
    qDebug() << "ProteinTableProxyModel::onTableClicked begin " << this->mapToSource(index).row();

    //_protein_table_model_p->onTableClicked(this->mapToSource(index));
    QModelIndex source_index(this->mapToSource(index));
    int row = source_index.row();
    int col = source_index.column();
    ProteinMatch* p_protein_match = _protein_table_model_p->getIdentificationGroup()->getProteinMatchList().at(row);
    if (col == 0) //add a checkbox to cell(1,0)
    {

        if ( p_protein_match->isChecked()) {
            p_protein_match->setChecked(false);
        }
        else {
            p_protein_match->setChecked(true);
        }
        _p_protein_list_window->edited();
    }
    else {
        if ((col == 2)||(col == 3)) {
            _p_protein_list_window->askProteinDetailView(p_protein_match);
        }
        else {
            _p_protein_list_window->askPeptideListView(p_protein_match);
        }
    }
    qDebug() << "ProteinTableProxyModel::onTableClicked end " << index.row();

}

bool ProteinTableProxyModel::lessThan(const QModelIndex & left, const QModelIndex & right) const {
    QVariant leftData = sourceModel()->data(left);
    QVariant rightData = sourceModel()->data(right);
    if (leftData.type() == QVariant::UInt) {
        return leftData.toUInt() < rightData.toUInt();
    }
    if (leftData.type() == QVariant::UInt) {
        return leftData.toUInt() < rightData.toUInt();
    }
    if (leftData.type() == QVariant::Double) {
        return leftData.toDouble() < rightData.toDouble();
    }
    return leftData.toString() < rightData.toString();
    //if (leftData.type() == QVariant::DateTime) {
    //   return leftData.toDateTime() < rightData.toDateTime();
    //} else {
    // static QRegExp emailPattern("[\\w\\.]*@[\\w\\.]*)");
    /*
            QString leftString = leftData.toString();
            if(left.column() == 1 && emailPattern.indexIn(leftString) != -1)
                leftString = emailPattern.cap(1);

            QString rightString = rightData.toString();
            if(right.column() == 1 && emailPattern.indexIn(rightString) != -1)
                rightString = emailPattern.cap(1);

            return QString::localeAwareCompare(leftString, rightString) < 0;
            */
    // }
}

QVariant ProteinTableProxyModel::headerData(int section, Qt::Orientation orientation,
        int role) const {
    return sourceModel()->headerData(section, orientation,
                                     role);
}

void ProteinTableProxyModel::hideNotValid(bool hide) {
    _hide_not_valid = hide;
}

void ProteinTableProxyModel::hideNotChecked(bool hide) {
    qDebug() << "ProteinTableProxyModel::hideNotChecked begin ";
    _hide_not_checked = hide;
    qDebug() << "ProteinTableProxyModel::hideNotChecked end ";
}
void ProteinTableProxyModel::hideNotGrouped(bool hide) {
    _hide_not_grouped = hide;
}
void ProteinTableProxyModel::setSearchOn(QString search_on) {
    _search_on = search_on;
}
void ProteinTableProxyModel::setProteinSearchString(QString protein_search_string) {
    _protein_search_string = protein_search_string;
}
